package com.ruoyi.sip.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.sip.domain.PartnerInfo;
import com.ruoyi.sip.service.IPartnerInfoService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 供应商管理Controller
 * 
 * @author mula
 * @date 2025-04-30
 */
@Controller
@RequestMapping("/system/partner")
public class PartnerInfoController extends BaseController
{
    private String prefix = "system/partner";

    @Autowired
    private IPartnerInfoService partnerInfoService;

    @RequiresPermissions("system:partner:view")
    @GetMapping()
    public String partner()
    {
        return prefix + "/partner";
    }

    /**
     * 查询供应商管理列表
     */
    @RequiresPermissions("system:partner:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(PartnerInfo partnerInfo)
    {
        startPage();
        List<PartnerInfo> list = partnerInfoService.selectPartnerInfoList(partnerInfo);
        return getDataTable(list);
    }

    /**
     * 导出供应商管理列表
     */
    @RequiresPermissions("system:partner:export")
    @Log(title = "供应商管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(PartnerInfo partnerInfo)
    {
        List<PartnerInfo> list = partnerInfoService.selectPartnerInfoList(partnerInfo);
        ExcelUtil<PartnerInfo> util = new ExcelUtil<PartnerInfo>(PartnerInfo.class);
        return util.exportExcel(list, "供应商管理数据");
    }

    /**
     * 新增供应商管理
     */
    @RequiresPermissions("system:partner:add")
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存供应商管理
     */
    @RequiresPermissions("system:partner:add")
    @Log(title = "供应商管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(PartnerInfo partnerInfo)
    {
        return toAjax(partnerInfoService.insertPartnerInfo(partnerInfo));
    }

    /**
     * 修改供应商管理
     */
    @RequiresPermissions("system:partner:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        PartnerInfo partnerInfo = partnerInfoService.selectPartnerInfoById(id);
        mmap.put("partnerInfo", partnerInfo);
        return prefix + "/edit";
    }

    /**
     * 修改保存供应商管理
     */
    @RequiresPermissions("system:partner:edit")
    @Log(title = "供应商管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(PartnerInfo partnerInfo)
    {
        return toAjax(partnerInfoService.updatePartnerInfo(partnerInfo));
    }

    /**
     * 删除供应商管理
     */
    @RequiresPermissions("system:partner:remove")
    @Log(title = "供应商管理", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(partnerInfoService.deletePartnerInfoByIds(ids));
    }
}
